from setuptools import setup, find_packages

setup(
    name="pykospacing2",
    version="0.1.0",
    packages=find_packages(),
    install_requires=[],
    author="Your Name",
    author_email="your.email@example.com",
    description="A Korean spacing correction library",
    long_description="A Korean spacing correction library",
    long_description_content_type="text/plain",
    url="https://github.com/yourusername/pykospacing2",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
) 